Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(898)

Unified Diff: content/browser/download/base_file.h

Issue 2890853002: Downloads: replace BrowserThread::FILE with task scheduler. (Closed)
Patch Set: Address Avi's comments. Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/BUILD.gn ('k') | content/browser/download/base_file.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/download/base_file.h
diff --git a/content/browser/download/base_file.h b/content/browser/download/base_file.h
index e630d778cfd88e68748c33574d124c7e260fcc7d..8b5487770515f6ab7f4f0884f6e03fd9349fa49c 100644
--- a/content/browser/download/base_file.h
+++ b/content/browser/download/base_file.h
@@ -16,6 +16,7 @@
#include "base/gtest_prod_util.h"
#include "base/logging.h"
#include "base/macros.h"
+#include "base/sequence_checker.h"
#include "base/time/time.h"
#include "content/common/content_export.h"
#include "content/public/browser/download_interrupt_reasons.h"
@@ -34,7 +35,7 @@ namespace content {
class CONTENT_EXPORT BaseFile {
public:
// May be constructed on any thread. All other routines (including
// destruction) must occur on the FILE thread.
BaseFile(const net::NetLogWithSource& net_log);
~BaseFile();
@@ -253,6 +254,8 @@ class CONTENT_EXPORT BaseFile {
net::NetLogWithSource net_log_;
+ SEQUENCE_CHECKER(sequence_checker_);
+
DISALLOW_COPY_AND_ASSIGN(BaseFile);
};
« no previous file with comments | « content/browser/BUILD.gn ('k') | content/browser/download/base_file.cc » ('j') | no next file with comments »
@@ -34,7 +35,7 @@ namespace content {
public:
// May be constructed on any thread. All other routines (including
- // destruction) must occur on the FILE thread.
+ // destruction) must occur on the same sequence.
BaseFile(const net::NetLogWithSource& net_log);
~BaseFile();

Powered by Google App Engine
This is Rietveld 408576698